summaryrefslogtreecommitdiff
path: root/IntelFrameworkModulePkg/Bus/Pci
diff options
context:
space:
mode:
authorxli24 <xli24@6f19259b-4bc3-4df7-8a09-765794883524>2009-06-19 09:35:07 +0000
committerxli24 <xli24@6f19259b-4bc3-4df7-8a09-765794883524>2009-06-19 09:35:07 +0000
commit7698f336b7c7cbd88805d21052e52e4129707da4 (patch)
treefaaa595535711248848a99e997f8eac35330982d /IntelFrameworkModulePkg/Bus/Pci
parent0f13d71cfb2711b95d45bf750ccd3f21c8db1a9e (diff)
downloadedk2-platforms-7698f336b7c7cbd88805d21052e52e4129707da4.tar.xz
Refine include file for PCI Platform Protocol, and update C source code accordingly.
git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@8614 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'IntelFrameworkModulePkg/Bus/Pci')
-rw-r--r--IntelFrameworkModulePkg/Bus/Pci/PciBusDxe/PciEnumerator.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/IntelFrameworkModulePkg/Bus/Pci/PciBusDxe/PciEnumerator.c b/IntelFrameworkModulePkg/Bus/Pci/PciBusDxe/PciEnumerator.c
index c8cd57a514..b14a018994 100644
--- a/IntelFrameworkModulePkg/Bus/Pci/PciBusDxe/PciEnumerator.c
+++ b/IntelFrameworkModulePkg/Bus/Pci/PciBusDxe/PciEnumerator.c
@@ -1727,9 +1727,9 @@ NotifyPhase (
HostBridgeHandle = PciRootBridgeIo->ParentHandle;
//
// Call PlatformPci::PhaseNotify() if the protocol is present.
//
- gPciPlatformProtocol->PhaseNotify (
+ gPciPlatformProtocol->PlatformNotify (
gPciPlatformProtocol,
HostBridgeHandle,
Phase,
@@ -1744,9 +1744,9 @@ NotifyPhase (
if (gPciPlatformProtocol != NULL) {
//
// Call PlatformPci::PhaseNotify() if the protocol is present.
//
- gPciPlatformProtocol->PhaseNotify (
+ gPciPlatformProtocol->PlatformNotify (
gPciPlatformProtocol,
HostBridgeHandle,
Phase,
@@ -1727,9 +1727,9 @@ NotifyPhase (
HostBridgeHandle = PciRootBridgeIo->ParentHandle;
//
- // Call PlatformPci::PhaseNotify() if the protocol is present.
+ // Call PlatformPci::PlatformNotify() if the protocol is present.
//
@@ -1744,9 +1744,9 @@ NotifyPhase (
if (gPciPlatformProtocol != NULL) {
//
- // Call PlatformPci::PhaseNotify() if the protocol is present.
+ // Call PlatformPci::PlatformNotify() if the protocol is present.
//